<?php

/**
 * Registrira postavke dodatka.
 */
function ep_hak_settings_register()
{
    add_settings_section(
        'woocommerce',
        'WooCommerce',
        function() {
            ?><p>Kako bi HAK kupon radio, morate kreirati stvarni kupon u WooCommerce-u i odabrati ga ovdje.</p><?php
        },
        'ep-hak'
    );

    add_settings_field(
        'coupon',
        'Kupon',
        'ep_hak_settings_form_coupon',
        'ep-hak',
        'woocommerce'
    );

	add_settings_section(
		'api',
		'HAK API',
		function() {
			?><p>Ovdje unosite vjerodajnice za spajanje na HAK API.</p><?php
		},
		'ep-hak'
	);

	add_settings_field(
		'device',
		'Uređaj',
		'ep_hak_settings_form_input_text',
		'ep-hak',
		'api',
		['device']
	);

	add_settings_field(
		'username',
		'Korisničko ime',
		'ep_hak_settings_form_input_text',
		'ep-hak',
		'api',
		['username']
	);

	add_settings_field(
		'token',
		'Token',
		'ep_hak_settings_form_input_text',
		'ep-hak',
		'api',
		['token']
	);

	register_setting('ep_hak', 'ep_hak');
}

/**
 * Dodaje stranicu s postavkama u izbornik.
 */
function ep_hak_settings_menu_item()
{
	add_options_page(
		'HAK Postavke',
		'HAK',
		'manage_options',
		'ep-hak',
		'ep_hak_settings_page'
	);
}

/**
 * Renderira stranicu s postavkama.
 */
function ep_hak_settings_page()
{
	?>
	<div class="wrap">
		<h2><?= get_admin_page_title(); ?></h2>

		<form method="post" action="options.php">
			<?php
			settings_fields('ep_hak');
			do_settings_sections('ep-hak');
			submit_button();
			?>
		</form>
	</div>
	<?php
}

/**
 * Renderira polje obrasca za postavku.
 *
 * @param string[] $args
 */
function ep_hak_settings_form_input_text(array $args)
{
	$options = get_option('ep_hak');
	$name = array_shift($args);
	$description = array_shift($args);

	printf(
		'<input type="text" name="ep_hak[%s]" id="%s" value="%s">%s',
		$name, $name,
		isset($options[$name]) ? esc_attr($options[$name]) : '',
		$description ? sprintf('<p class="description">%s</p>', esc_html($description)) : ''
	);
}

/**
 * Renderira polje za odabir kupona.
 */
function ep_hak_settings_form_coupon()
{
    $options = get_option('ep_hak');
    $current = isset($options['coupon']) ? $options['coupon'] : null;

    $coupons = get_posts([
        'post_type' => 'shop_coupon',
    ]);

    $options = array_map(function(WP_Post $coupon) use ($current) {
        return sprintf(
            '<option value="%s" %s>%s</option>',
            $coupon->post_title,
            $coupon->post_title === $current ? 'selected' : '',
            esc_html($coupon->post_title)
        );
    }, $coupons);

    printf(
        '<select name="ep_hak[coupon]" id="coupon">%s%s</select>',
        '<option value="">-</option>',
        implode("\n", $options)
    );
}