const path = require('path');
const CleanPlugin = require('clean-webpack-plugin');
const ManifestPlugin = require('webpack-manifest-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const ProvidePlugin = require('webpack/lib/ProvidePlugin');
const UglifyJSWebpackPlugin = require('uglifyjs-webpack-plugin');

module.exports = {
    entry: {
        'ep-hak': './assets/checkout.js'
    },
    output: {
        filename: 'js/[name].[hash].js',
        path: path.resolve(__dirname, 'dist')
    },

    plugins: [
        new CleanPlugin(['dist']),
        new ExtractTextPlugin({
            filename: 'css/[name].[hash].css'
        }),
        new ManifestPlugin(),
        new ProvidePlugin({
            $: 'jquery'
        }),
        new UglifyJSWebpackPlugin()
    ],

    module: {
        rules: [{
            test: /\.scss$/,
            exclude: /node_modules/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [{
                    loader: 'css-loader',
                    options: {
                        importLoaders: 2,
                        sourceMap: true
                    }
                }, {
                    loader: 'postcss-loader',
                    options: {
                        ident: 'postcss',
                        sourceMap: true,
                        plugins: [
                            require('autoprefixer'),
                            require('cssnano')({
                                postcssReduceIdents: false,
                                zindex: false
                            })
                        ]
                    }
                }, {
                    loader: 'sass-loader',
                    options: {
                        sourceMap: true
                    }
                }]
            })
        }, {
            test: /\.js$/,
            loader: 'babel-loader',
            options: {
                presets: ['env']
            }
        }]
    },

    externals: {
        jquery: 'jQuery'
    }
};